package
Version:
v1.6.4
Opens a new window with list of versions in this module.
Published: May 2, 2026
License: AGPL-3.0
Opens a new window with license information.
Imports: 10
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GenerateSelfSigned(certPath, keyPath, domain string) error
GenerateSelfSigned creates a self-signed ECDSA P-256 certificate.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.