keys

package
v1.6.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 10, 2026 License: AGPL-3.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GenerateDNSTTKeys

func GenerateDNSTTKeys(privKeyPath, pubKeyPath string) (string, error)

GenerateDNSTTKeys generates a Curve25519 keypair and writes them to files. Returns the hex-encoded public key.

func ImportDNSTTKeyPair

func ImportDNSTTKeyPair(privKeyHex, pubKeyHex, privKeyPath, pubKeyPath string) (string, error)

ImportDNSTTKeyPair validates a hex-encoded private and public key pair, verifies they match, and writes both to files. Returns the hex-encoded public key.

func ImportDNSTTKeys

func ImportDNSTTKeys(privKeyHex, privKeyPath, pubKeyPath string) (string, error)

ImportDNSTTKeys validates a hex-encoded private key, derives its public key, and writes both to files. Returns the hex-encoded public key.

func ReadPublicKey

func ReadPublicKey(path string) (string, error)

ReadPublicKey reads a hex-encoded public key file.

Types

This section is empty.

Jump to