transport

package
v1.6.0-dev Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 5, 2026 License: AGPL-3.0 Imports: 10 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateService

func CreateService(tunnel *config.TunnelConfig, cfg *config.Config) error

CreateService creates and starts a systemd service for a tunnel.

func EnsureInstalled

func EnsureInstalled(transport string) error

EnsureInstalled downloads the binary for a transport if not already present.

func RemoveService

func RemoveService(tag string) error

RemoveService stops and removes a tunnel's systemd service.

Types

This section is empty.

Jump to