Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GenerateDNSTTKeys ¶
GenerateDNSTTKeys generates a Curve25519 keypair and writes them to files. Returns the hex-encoded public key.
func ImportDNSTTKeyPair ¶
ImportDNSTTKeyPair validates a hex-encoded private and public key pair, verifies they match, and writes both to files. Returns the hex-encoded public key.
func ImportDNSTTKeys ¶
ImportDNSTTKeys validates a hex-encoded private key, derives its public key, and writes both to files. Returns the hex-encoded public key.
func ReadPublicKey ¶
ReadPublicKey reads a hex-encoded public key file.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.