network

package
v1.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 9, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AllowPort

func AllowPort(port int, proto string) error

AllowPort opens a port using the first available firewall tool.

func DisableResolvedStub

func DisableResolvedStub() error

DisableResolvedStub disables systemd-resolved's DNS stub listener on port 53 so that slipgate's DNS router can bind to it.

func FreePort added in v1.3.1

func FreePort(port int, proto string) error

FreePort kills any process listening on the given port/protocol. Uses fuser if available, falls back to lsof + kill.

func RemovePort

func RemovePort(port int, proto string) error

RemovePort removes a firewall rule for a port.

Types

This section is empty.

Jump to