Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DisableResolvedStub ¶
func DisableResolvedStub() error
DisableResolvedStub disables systemd-resolved's DNS stub listener on port 53 so that slipgate's DNS router can bind to it.
func FreePort ¶ added in v1.3.1
FreePort kills any process listening on the given port/protocol. Uses fuser if available, falls back to lsof + kill.
func RemovePort ¶
RemovePort removes a firewall rule for a port.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.