Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AddSSHUser ¶
AddSSHUser creates a system user in the slipgate-ssh group. If the user already exists, it updates the password instead.
func EnsureUser ¶
func EnsureUser() error
EnsureUser creates the slipgate system user and groups if they don't exist.
func GeneratePassword ¶
GeneratePassword generates a random alphanumeric password.
func ListSSHUsers ¶
ListSSHUsers returns all users in the slipgate-ssh group.
func RemoveSSHUser ¶
RemoveSSHUser kills active sessions and removes a user from the system.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.