Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateService ¶
func CreateService(tunnel *config.TunnelConfig, cfg *config.Config) error
CreateService creates and starts a systemd service for a tunnel.
func EnsureInstalled ¶
EnsureInstalled downloads the binary for a transport if not already present.
func RemoveService ¶
RemoveService stops and removes a tunnel's systemd service.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.